@@ -1,3 +1,3 @@
 from .file_io import FileIO
 from .hdfs import Hdfs
-from .local import Local
\ No newline at end of file
+from .filesystem import Filesystem
\ No newline at end of file
