@@ -8,13 +8,13 @@ class FileIO(ABC):
         
         
         if 'storage_type' in kw:
-            storage_type = kw['storage_type'].capitalize()
+            storage_type = kw['storage_type'].lower()
         elif len(args) > 0:
             storage_type = args[0]
         elif get_argument("webHdfsUrl") is not None:
             storage_type = "hdfs"
         else:
-            storage_type = "Filesystem"
+            storage_type = "filesystem"
 
         # Create a map of all subclasses based on storage type property (present on each subclass)
         subclass_map = {subclass.storage_type: subclass for subclass in cls.__subclasses__()}
