@@ -22,7 +22,7 @@ class Filesystem(FileIO):
 
     def copy_tree_or_file(self, from_path, to_path):
         if not os.path.exists(from_path):
-            raise("File or folder not present! Be sure that you're saving your model correctly.")
+            raise Exception("File or folder not present! Be sure that you're saving your file (model?) correctly.")
         # If it's a folder (compliant with older versions of python, now better ways are present).
         try:
             copy_tree(from_path, to_path)
